@@ -1,3 +1,5 @@
+import os
+from datetime import datetime
 from typing import Any, Dict, List, Optional
 
 from fastapi import APIRouter, Depends, Path, Query, Request, Response, status
@@ -18,7 +20,11 @@ from contaxy.schema.exceptions import (
 from contaxy.schema.extension import EXTENSION_ID_PARAM
 from contaxy.schema.file import FILE_KEY_PARAM
 from contaxy.schema.project import PROJECT_ID_PARAM
-from contaxy.schema.shared import OPEN_URL_REDIRECT, RESOURCE_ID_REGEX
+from contaxy.schema.shared import (
+    MAX_DISPLAY_NAME_LENGTH,
+    OPEN_URL_REDIRECT,
+    RESOURCE_ID_REGEX,
+)
 from contaxy.utils.auth_utils import get_api_token
 from contaxy.utils.file_utils import FormMultipartStream, SyncFromAsyncGenerator
 
@@ -120,6 +126,16 @@ def upload_file(
             )
         file_key = multipart_stream.filename
 
+    file_name = os.path.basename(file_key)
+    if len(file_name) > MAX_DISPLAY_NAME_LENGTH:
+        raise ClientValueError(
+            "Error in uploading file "
+            + file_name
+            + ". File name is more than "
+            + str(MAX_DISPLAY_NAME_LENGTH)
+            + " characters."
+        )
+
     metadata = {}
     for key, value in request.headers.items():
         if key.startswith(_FILE_METADATA_PREFIX):
@@ -410,6 +426,14 @@ def delete_file(
 )
 def delete_files(
     project_id: str = PROJECT_ID_PARAM,
+    date_from: Optional[datetime] = Query(
+        None,
+        description="The start date to delete the files. If not specified, all files will be deleted.",
+    ),
+    date_to: Optional[datetime] = Query(
+        None,
+        description="The end date to delete the files. If not specified, all files will be deleted.",
+    ),
     extension_id: Optional[str] = EXTENSION_ID_PARAM,
     component_manager: ComponentManager = Depends(get_component_manager),
     token: str = Depends(get_api_token),
@@ -419,7 +443,9 @@ def delete_files(
         token, f"projects/{project_id}/files", AccessLevel.ADMIN
     )
 
-    component_manager.get_file_manager(extension_id).delete_files(project_id)
+    component_manager.get_file_manager(extension_id).delete_files(
+        project_id, date_from, date_to
+    )
     return Response(status_code=status.HTTP_204_NO_CONTENT)
 
 
