@@ -1,11 +1,11 @@
-from typing import Any, List
+from typing import Any, List, Union
 
 from fastapi import APIRouter, Depends, Query, Response, status
 from fastapi.param_functions import Body
 
 from contaxy.api.dependencies import ComponentManager, get_component_manager
 from contaxy.schema import CoreOperations, User, UserInput, UserRegistration
-from contaxy.schema.auth import USER_ID_PARAM, AccessLevel
+from contaxy.schema.auth import USER_ID_PARAM, AccessLevel, UserRead
 from contaxy.schema.exceptions import (
     AUTH_ERROR_RESPONSES,
     CREATE_RESOURCE_RESPONSES,
@@ -28,8 +28,8 @@ router = APIRouter(
 @router.get(
     "/users",
     operation_id=CoreOperations.LIST_USERS.value,
-    response_model=List[User],
-    response_model_exclude_unset=False,
+    response_model=List[Union[User, UserRead]],
+    response_model_exclude_unset=True,
     summary="List all users.",
     tags=["users"],
     status_code=status.HTTP_200_OK,
@@ -39,10 +39,13 @@ def list_users(
     token: str = Depends(get_api_token),
 ) -> Any:
     """Lists all users that are visible to the authenticated user."""
-    component_manager.verify_access(
-        token, "users", AccessLevel.READ
-    )  # TODO: the right permission?
-    return component_manager.get_auth_manager().list_users()
+    try:
+        component_manager.verify_access(token, "users", AccessLevel.ADMIN)
+        return component_manager.get_auth_manager().list_users(AccessLevel.ADMIN)
+    except PermissionDeniedError:
+        # If the user does not have admin access, a limited view of the users is still allowed
+        component_manager.verify_access(token)
+        return component_manager.get_auth_manager().list_users(AccessLevel.READ)
 
 
 @router.post(
@@ -188,14 +191,27 @@ def change_password(
 
     The password is stored as a hash.
     """
-    # TODO: check existing password as well for normal users
-    if not component_manager.global_state.settings.PASSWORD_AUTH_ENABLED:
-        # Admins still can set and change password
+    try:
         component_manager.verify_access(token, "users", AccessLevel.ADMIN)
-    else:
-        # Only check if token allows admin access on user object
+        is_admin = True
+    except PermissionDeniedError:
+        is_admin = False
+        # Check if token allows admin access on user object
         component_manager.verify_access(token, f"users/{user_id}", AccessLevel.ADMIN)
 
+    if (
+        not component_manager.global_state.settings.PASSWORD_AUTH_ENABLED
+        and not is_admin
+    ):
+        raise PermissionDeniedError("Password authentication is not enabled!")
+
+    if (
+        not component_manager.get_auth_manager().get_user(user_id).has_password
+        and not is_admin
+    ):
+        raise PermissionDeniedError("Cannot set password for SSO user!")
+
+    # TODO: check existing password as well for normal users
     component_manager.get_auth_manager().change_password(user_id, password)
     return Response(status_code=status.HTTP_204_NO_CONTENT)
 
