@@ -1,6 +1,7 @@
 import json
 import logging
 import os
+from datetime import datetime
 from typing import IO, Dict, Iterator, List, Optional, Tuple
 
 from azure.core.exceptions import AzureError, HttpResponseError
@@ -402,31 +403,47 @@ class AzureBlobFileManager(FileOperations):
     def delete_files(
         self,
         project_id: str,
+        date_from: Optional[datetime] = None,
+        date_to: Optional[datetime] = None,
     ) -> None:
         """Delete all files and storage resources related to a project.
 
         Args:
             project_id (str): Project ID associated with the files.
-        """
-        container_name = get_container_name(
-            project_id, self._global_state.settings.SYSTEM_NAMESPACE
-        )
-        try:
-            container_client = self.client.get_container_client(container_name)
-            container_client.delete_container()
-        except AzureResourceNotFoundError:
-            logger.info(
-                f"Project container {container_name} to deleted as it does not exist."
-            )
-            return
-        except AzureError as e:
-            raise ServerBaseError(
-                f"Project container {container_name} could not be deleted."
-            ) from e
+            date_from (Optional[datetime], optional): The start date to delete the files. If not specified, all files will be deleted.
+            date_to (Optional[datetime], optional): The end date to delete the files. If not specified, all files will be deleted.
 
-        self.json_db_manager.delete_json_collection(
-            project_id, self.DOC_COLLECTION_NAME
-        )
+        Raises:
+            ServerBaseError: Exception
+        """
+        if date_from and date_to:
+            files_to_delete = self.list_files(project_id)
+
+            for file in files_to_delete:
+                if file.updated_at and (
+                    (date_to.date() >= file.updated_at.date() >= date_from.date())
+                ):
+                    self.delete_file(project_id, file.key)
+        else:
+            container_name = get_container_name(
+                project_id, self._global_state.settings.SYSTEM_NAMESPACE
+            )
+            try:
+                container_client = self.client.get_container_client(container_name)
+                container_client.delete_container()
+            except AzureResourceNotFoundError:
+                logger.info(
+                    f"Project container {container_name} to deleted as it does not exist."
+                )
+                return
+            except AzureError as e:
+                raise ServerBaseError(
+                    f"Project container {container_name} could not be deleted."
+                ) from e
+
+            self.json_db_manager.delete_json_collection(
+                project_id, self.DOC_COLLECTION_NAME
+            )
 
     def list_file_actions(
         self, project_id: str, file_key: str, version: Optional[str] = None
@@ -439,9 +456,9 @@ class AzureBlobFileManager(FileOperations):
         file_key: str,
         action_id: str,
         version: Optional[str] = None,
-    ) -> Response:
+    ) -> Optional[Response]:
         # TODO
-        pass
+        return None
 
     def _create_client(self) -> BlobServiceClient:
         settings = self._global_state.settings
